@@ -7,7 +7,11 @@
           $account_disabled_message, $report_abuse_too_many_recipients_message,
           $report_abuse_too_many_today_message, $whitelisted_addresses, $rs_delimiter,
           $log_too_many_recipients, $log_too_many_today,
-          $log_too_many_subsequent_mass_emails, $log_no_recipients;
+          $log_too_many_subsequent_mass_emails, $log_no_recipients,
+          $rs_useSendmail, $rs_smtpServerAddress, $rs_smtpPort,
+          $rs_sendmail_path, $rs_sendmail_args, $rs_pop_before_smtp,
+          $rs_encode_header_key, $rs_smtp_auth_mech,
+          $rs_smtp_sitewide_user, $rs_smtp_sitewide_pass;
 
 
 
@@ -230,3 +234,24 @@
 
 
 
+   // When sending administrative alert messages, you may want to send
+   // them using different SMTP authentication credentials or change
+   // any of the other Sendmail or SMTP settings used normally in
+   // SquirrelMail's normal use for sending mail.  If so, change the
+   // appropriate setting here.  These values MUST be set to "NULL"
+   // to indicate that the normal SquirrelMail configuration values
+   // are to be used.
+   //
+   $rs_useSendmail = NULL;
+   $rs_smtpServerAddress = NULL;
+   $rs_smtpPort = NULL;
+   $rs_sendmail_path = NULL;
+   $rs_sendmail_args = NULL;
+   $rs_pop_before_smtp = NULL;
+   $rs_encode_header_key = NULL;
+   $rs_smtp_auth_mech = NULL;
+   $rs_smtp_sitewide_user = NULL;
+   $rs_smtp_sitewide_pass = NULL;
+
+
+
