@@ -1472,7 +1472,15 @@ function rs_report_abuse($error, $title='', $message='')
    $delim = '@';
 
    global $rs_report_addresses, $domain, $username,
-          $rs_use_Vadmin_delete_link;
+          $rs_use_Vadmin_delete_link, $rs_useSendmail,
+          $rs_smtpServerAddress, $rs_smtpPort,
+          $rs_sendmail_path, $rs_sendmail_args,
+          $rs_pop_before_smtp, $rs_encode_header_key,
+          $rs_smtp_auth_mech, $rs_smtp_sitewide_user,
+          $rs_smtp_sitewide_pass, $useSendmail, $smtpServerAddress,
+          $smtpPort, $sendmail_path, $sendmail_args, $pop_before_smtp,
+          $encode_header_key, $smtp_auth_mech, $smtp_sitewide_user,
+          $smtp_sitewide_pass;
 
 
    // get global variable for versions of PHP < 4.1
@@ -1529,6 +1537,40 @@ function rs_report_abuse($error, $title='', $message='')
    sq_change_text_domain('squirrelmail');
 
 
+   // override any SMTP/Sendmail settings...
+   //
+   $orig_useSendmail = $useSendmail;
+   if (!is_null($rs_useSendmail))
+      $useSendmail = $rs_useSendmail;
+   $orig_smtpServerAddress = $smtpServerAddress;
+   if (!is_null($rs_smtpServerAddress))
+      $smtpServerAddress = $rs_smtpServerAddress;
+   $orig_smtpPort = $smtpPort;
+   if (!is_null($rs_smtpPort))
+      $smtpPort = $rs_smtpPort;
+   $orig_sendmail_path = $sendmail_path;
+   if (!is_null($rs_sendmail_path))
+      $sendmail_path = $rs_sendmail_path;
+   $orig_sendmail_args = $sendmail_args;
+   if (!is_null($rs_sendmail_args))
+      $sendmail_args = $rs_sendmail_args;
+   $orig_pop_before_smtp = $pop_before_smtp;
+   if (!is_null($rs_pop_before_smtp))
+      $pop_before_smtp = $rs_pop_before_smtp;
+   $orig_encode_header_key = $encode_header_key;
+   if (!is_null($rs_encode_header_key))
+      $encode_header_key = $rs_encode_header_key;
+   $orig_smtp_auth_mech = $smtp_auth_mech;
+   if (!is_null($rs_smtp_auth_mech))
+      $smtp_auth_mech = $rs_smtp_auth_mech;
+   $orig_smtp_sitewide_user = $smtp_sitewide_user;
+   if (!is_null($rs_smtp_sitewide_user))
+      $smtp_sitewide_user = $rs_smtp_sitewide_user;
+   $orig_smtp_sitewide_pass = $smtp_sitewide_pass;
+   if (!is_null($rs_smtp_sitewide_pass))
+      $smtp_sitewide_pass = $rs_smtp_sitewide_pass;
+
+
    // function found in SM core 1.5.2+ and Compatibility plugin 2.0.11+
    // (suppress include error, since file is only needed for 1.5.2+,
    // otherwise Compatibility has us covered)
@@ -1536,6 +1578,20 @@ function rs_report_abuse($error, $title='', $message='')
    @include_once(SM_PATH . 'functions/compose.php');
    $success = sq_send_mail($rs_report_addresses, $subject, $body, 'noreply@' . $domain);
 
+
+   // return SMTP/Sendmail settings to what they were
+   //
+   $useSendmail = $orig_useSendmail;
+   $smtpServerAddress = $orig_smtpServerAddress;
+   $smtpPort = $orig_smtpPort;
+   $sendmail_path = $orig_sendmail_path;
+   $sendmail_args = $orig_sendmail_args;
+   $pop_before_smtp = $orig_pop_before_smtp;
+   $encode_header_key = $orig_encode_header_key;
+   $smtp_auth_mech = $orig_smtp_auth_mech;
+   $smtp_sitewide_user = $orig_smtp_sitewide_user;
+   $smtp_sitewide_pass = $orig_smtp_sitewide_pass;
+
 }
 
 
